==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/ja/toolbar.py <==
# Japanese lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "新しいドキュメント",
    "actions_accessible_name_new_document": "新しいドキュメント",
    "actions_label_open": "開く",
    "actions_accessible_name_open": "ドキュメントを開く",
    "actions_label_save": "保存",
    "actions_accessible_name_save": "ドキュメントを保存",
    "actions_label_save_as": "名前を付けて保存",
    "actions_accessible_name_save_as": "ドキュメントのコピーを保存",
    "actions_label_sync": "同期",
    "actions_accessible_name_sync": "ドキュメントを外部ストレージと同期",
    "actions_label_edit": "編集",
    "actions_accessible_name_edit": "ファイルを編集",
    "actions_label_source": "ソース",
    "actions_accessible_name_source": "ソースコード",
    "actions_label_encrypt": "暗号化",
    "actions_accessible_name_encrypt": "ファイルを暗号化",
    "actions_label_decrypt": "復号",
    "actions_accessible_name_decrypt": "ファイルを復号",
    "actions_label_bold": "太字",
    "actions_accessible_name_bold": "太字テキストフォーマット",
    "actions_label_italic": "イタリック",
    "actions_accessible_name_italic": "イタリックテキストフォーマット",
    "actions_label_underline": "下線",
    "actions_accessible_name_underline": "下線テキストフォーマット",
    "actions_label_strikethrough": "取り消し線",
    "actions_accessible_name_strikethrough": "取り消し線テキストフォーマット",
    "actions_label_blockquote": "ブロック引用",
    "actions_accessible_name_blockquote": "ブロック引用テキストフォーマット",
    "actions_label_color_picker": "カラーピッカー",
    "actions_accessible_name_color_picker": "テキストの色を選択",
    "actions_label_ai_assistant": "AI アシスタント",
    "actions_accessible_name_ai_assistant": "AI アシスタントを実行",
    "actions_label_about": "アバウト",
    "actions_accessible_name_about": "アプリについて",
    "actions_label_exit": "終了",
    "actions_accessible_name_exit": "アプリを終了",
    "actions_label_settings": "設定",
    "actions_accessible_name_settings": "アプリ設定",

    "search_input_label": "検索",
    "search_input_placeholder_text": "ドキュメント内のテキスト",
    "search_input_accessible_description": "検索入力フィールド",
    "search_buttons_label_clear": "検索をクリア",
    "search_buttons_accessible_name_clear": "検索入力フィールドをクリア",
    "search_buttons_label_prev": "前の検索",
    "search_buttons_accessible_name_prev": "前の検索結果",
    "search_buttons_label_next": "次の検索",
    "search_buttons_accessible_name_next": "次の検索結果",
    "search_case_sensitive_label": "大文字と小文字を区別",
    "search_case_sensitive_tooltip": "大文字と小文字を区別する検索",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/ja/toolbar.py <==
# Japanese lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "新しいドキュメント",
    "actions_accessible_name_new_document": "新しいドキュメント",
    "actions_label_open": "開く",
    "actions_accessible_name_open": "ドキュメントを開く",
    "actions_label_save": "保存",
    "actions_accessible_name_save": "ドキュメントを保存",
    "actions_label_save_as": "名前を付けて保存",
    "actions_accessible_name_save_as": "ドキュメントのコピーを保存",
    "actions_label_sync": "同期",
    "actions_accessible_name_sync": "ドキュメントを外部ストレージと同期",
    "actions_label_edit": "編集",
    "actions_accessible_name_edit": "ファイルを編集",
    "actions_label_source": "ソース",
    "actions_accessible_name_source": "ソースコード",
    "actions_label_encrypt": "暗号化",
    "actions_accessible_name_encrypt": "ファイルを暗号化",
    "actions_label_decrypt": "復号",
    "actions_accessible_name_decrypt": "ファイルを復号",
    "actions_label_bold": "太字",
    "actions_accessible_name_bold": "太字テキストフォーマット",
    "actions_label_italic": "イタリック",
    "actions_accessible_name_italic": "イタリックテキストフォーマット",
    "actions_label_underline": "下線",
    "actions_accessible_name_underline": "下線テキストフォーマット",
    "actions_label_strikethrough": "取り消し線",
    "actions_accessible_name_strikethrough": "取り消し線テキストフォーマット",
    "actions_label_blockquote": "ブロック引用",
    "actions_accessible_name_blockquote": "ブロック引用テキストフォーマット",
    "actions_label_color_picker": "カラーピッカー",
    "actions_accessible_name_color_picker": "テキストの色を選択",
    "actions_label_ai_assistant": "AI アシスタント",
    "actions_accessible_name_ai_assistant": "AI アシスタントを実行",
    "actions_label_about": "アバウト",
    "actions_accessible_name_about": "アプリについて",
    "actions_label_exit": "終了",
    "actions_accessible_name_exit": "アプリを終了",
    "actions_label_settings": "設定",
    "actions_accessible_name_settings": "アプリ設定",

    "search_input_label": "検索",
    "search_input_placeholder_text": "ドキュメント内のテキストを検索",
    "search_input_accessible_description": "検索入力フィールド",
    "search_buttons_label_clear": "検索をクリア",
    "search_buttons_accessible_name_clear": "検索入力フィールドをクリア",
    "search_buttons_label_prev": "前の検索",
    "search_buttons_accessible_name_prev": "前の検索結果",
    "search_buttons_label_next": "次の検索",
    "search_buttons_accessible_name_next": "次の検索結果",
    "search_case_sensitive_accessible_name": "大文字と小文字を区別",
    "search_case_sensitive_tooltip": "大文字と小文字を区別する検索",
}
